@@ -1,35 +1,6 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2022-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2022-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 """|UDM| module for monitoring alerts"""
 
@@ -155,7 +126,7 @@ def mapKeyAndValue(old, encoding=()):
     >>> mapKeyAndValue([("a", "b")])
     [b'a=b']
     """
-    return [u'='.join(entry).encode(*encoding) for entry in old]
+    return ['='.join(entry).encode(*encoding) for entry in old]
 
 
 def unmapKeyAndValue(old, encoding=()):
@@ -165,7 +136,7 @@ def unmapKeyAndValue(old, encoding=()):
     >>> unmapKeyAndValue([b"a=b"])
     [['a', 'b']]
     """
-    return [entry.decode(*encoding).split(u'=', 1) for entry in old]
+    return [entry.decode(*encoding).split('=', 1) for entry in old]
 
 
 mapping = univention.admin.mapping.mapping()
